@@ -37,6 +37,11 @@
 //
 
 #include <config.h>
+
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE   600
+#endif
+
 #include <commoncpp/config.h>
 #include <commoncpp/export.h>
 #include <commoncpp/string.h>
