@@ -16,6 +16,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/memory.h>
 #include <ucommon/thread.h>
 #include <ucommon/string.h>
@@ -467,6 +468,10 @@ chartext::chartext(char *buf, size_t size)
     max = size;
 }
 
+chartext::~chartext()
+{
+}
+
 int chartext::_getch(void)
 {
     if(!pos || !*pos || max)
