@@ -16,6 +16,7 @@
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
+#include <ucommon/export.h>
 #include <ucommon/string.h>
 #include <ucommon/memory.h>
 #include <ucommon/shell.h>
@@ -1073,10 +1074,9 @@ skip:
     return _argv;
 }
 
-void shell::errexit(int exitcode, const char *format, ...)
+void shell::error(const char *format, ...)
 {
     va_list args;
-    loglevel_t level = ERR;
     char buf[256];
 
     String::set(buf, sizeof(buf) - 1, format);
@@ -1099,11 +1099,8 @@ void shell::errexit(int exitcode, const char *format, ...)
 
     buf[len] = 0;
 
-    if(exitcode)
-        level = FAIL;
-
 #ifdef  HAVE_SYSLOG_H
-    if(errname && errmode != NONE && level <= errlevel) {
+    if(errname && errmode != NONE && (ERR <= errlevel)) {
         if(eq("*** ", format, 4)) {
             format += 4;
             const char *cp = format;
@@ -1112,18 +1109,56 @@ void shell::errexit(int exitcode, const char *format, ...)
             if(*cp == ':' && cp[1] == ' ')
                 format = cp + 2;
         }
+        vsyslog(LOG_ERR, format, args);
+    }
+#endif
+    va_end(args);
+}
 
-        if(exitcode)
-            vsyslog(LOG_CRIT, format, args);
-        else
-            vsyslog(LOG_ERR, format, args);
+void shell::errexit(int exitcode, const char *format, ...)
+{
+    if(!exitcode)
+        return;
+
+    va_list args;
+    char buf[256];
+
+    String::set(buf, sizeof(buf) - 1, format);
+    size_t len = strlen(buf);
+
+    if(buf[len - 1] != '\n') {
+        buf[len] = '\n';
+        buf[len + 1] = 0;
+    }
+    else
+        --len;
+
+    format = buf;
+
+    va_start(args, format);
+    if(!eq("*** ", format, 4))
+        fputs("*** ", stderr);
+    vfprintf(stderr, format, args);
+    fflush(stderr);
+
+    buf[len] = 0;
+
+#ifdef  HAVE_SYSLOG_H
+    if(errname && errmode != NONE && (FAIL <= errlevel)) {
+        if(eq("*** ", format, 4)) {
+            format += 4;
+            const char *cp = format;
+            while(isalnum(*cp) || *cp == '-' || *cp == '.')
+                ++cp;
+            if(*cp == ':' && cp[1] == ' ')
+                format = cp + 2;
+        }
+        vsyslog(LOG_CRIT, format, args);
     }
 #endif
 
     va_end(args);
-
-    if(exitcode)
-        ::exit(exitcode);
+    ::exit(exitcode);
 }
 
 size_t shell::readln(pipe_t pipe, char *buffer, size_t size)
@@ -1817,7 +1852,7 @@ char *shell::getline(const char *prompt, char *buffer, size_t size)
     fputs(prompt, stdout);
 
     while(pos < size - 1) {
-        buffer[pos] = ::getchar();
+        buffer[pos] = getc(stdin);
         if(buffer[pos] == '\r' || buffer[pos] == '\n')
             break;
         else if(buffer[pos] == '\b' && pos) {
@@ -1869,7 +1904,7 @@ int shell::inkey(const char *prompt)
     noecho(1);
     if(prompt)
         fputs(prompt, stdout);
-    int ch = ::getchar();
+    int ch = getc(stdin);
     echo(1);
 
     return ch;
@@ -2480,6 +2515,10 @@ void shell::debug(unsigned level, const char *fmt, ...)
 
 #ifdef  HAVE_SYSLOG_H
 
+#ifndef	LOG_AUTHPRIV
+#define	LOG_AUTHPRIV	LOG_AUTH
+#endif
+
 void shell::log(const char *name, loglevel_t level, logmode_t mode, logproc_t handler)
 {
     errlevel = level;
