@@ -35,8 +35,8 @@
 #ifndef _UCOMMON_STRING_H_
 #define _UCOMMON_STRING_H_
 
-#ifndef _UCOMMON_CONFIG_H_
-#include <ucommon/platform.h>
+#ifndef _UCOMMON_CPR_H_
+#include <ucommon/cpr.h>
 #endif
 
 #ifndef _UCOMMON_GENERICS_H_
