@@ -53,8 +53,8 @@
 #ifndef _UCOMMON_THREAD_H_
 #define _UCOMMON_THREAD_H_
 
-#ifndef _UCOMMON_CONFIG_H_
-#include <ucommon/platform.h>
+#ifndef _UCOMMON_CPR_H_
+#include <ucommon/cpr.h>
 #endif
 
 #ifndef _UCOMMON_ACCESS_H_
