@@ -132,6 +132,16 @@ public:
      */
     static size_t pack(unicode_t unicode, CharacterProtocol& buffer, size_t size);
 
+    /**
+     * Dup a utf8 string into a ucs4_t string.
+     */
+    static ucs4_t *udup(const char *string);
+
+    /**
+     * Dup a utf8 string into a ucs2_t representation.
+     */
+    static ucs2_t *wdup(const char *string);
+
     /**
      * Find first occurance of character in string.
      * @param string to search in.
@@ -480,6 +490,26 @@ public:
         {return utf8::count((const char *)text);};
 };
 
+inline ucs4_t *strudup(const char *string)
+    {return utf8::udup(string);}
+
+inline ucs2_t *strwdup(const char *string)
+    {return utf8::wdup(string);}
+
+__EXPORT unicode_t unidup(const char *string);
+
+template<>
+inline void dupfree<ucs2_t*>(ucs2_t *string)
+    {::free(string);}
+
+template<>
+inline void dupfree<ucs4_t*>(ucs4_t *string)
+    {::free(string);}
+
+template<>
+inline void dupfree<unicode_t>(unicode_t string)
+    {::free(string);}
+
 /**
  * Convenience type for utf8 encoded strings.
  */
